@@ -13,7 +13,10 @@ from tkdev.devicon import Icon_Empty
 from tkdev.devresize import DevResize
 from tkdev.devnet import WindowEffect
 import warnings
-from deprecated.sphinx import deprecated
+try:
+    from deprecated.sphinx import deprecated
+except ImportError:
+    pass
 
 try:
     from win32gui import *
@@ -510,6 +513,11 @@ class DevExtend(tk.Frame):
         self.extend_area.pack(fill=tk.BOTH, expand=tk.YES)
 
 
+class DevFoldFrame(tk.Frame):
+    def __init__(self):
+        super(DevFoldFrame, self).__init__()
+
+
 class DevHeaderBar(tk.Frame):
     def __init__(self, master: tk.Tk, border: bool = True, background="#ffffff", double_max: bool = True):
         super(DevHeaderBar, self).__init__(master=master, background=background, height=35)
@@ -974,15 +982,9 @@ class DevToast(tk.Toplevel):
         self.withdraw()
 
     def show_toast(self):
-        x = 20
-        y = 20
-        width = self.winfo_screenwidth() - x * 2
-        height = self.height
-
+        window_pos_bottom_right(self)
         self.deiconify()
-
-        self.geometry(f"{round(width)}x{round(height)}+{x}+{y}")
-        self.attributes("-topmost", True)
+        self.after(5000, self.withdraw)
 
 
 class DevWindow(tk.Tk):
@@ -1104,10 +1106,12 @@ class DevToplevel(tk.Toplevel, DevWindow):
 
 
 if __name__ == '__main__':
+    from tkdev import DevWindow, window_move
+    from tkinter import Frame
+
+    Install("cefpython3")
     Window = DevWindow()
-    HeaderBar = DevHeaderBar(Window, True)
-    HeaderBar.add_close_button()
-    HeaderBar.add_maximize_button()
-    HeaderBar.add_minimize_button()
-    Window.titlebar(HeaderBar)
-    Window.mainloop()
+    TitleBar = Frame(Window, height=35, background="#000000")
+    window_move(TitleBar, Window)
+    TitleBar.pack(fill="x")
+    Window.mainloop()
\ No newline at end of file
